#!/bin/bash -e
#
# $Id: build-updates.sh 16157 2019-07-12 01:38:41Z NiLuJe $
#

HACKNAME="dummy"
HACKDIR="TestUpdate"
PKGNAME="${HACKNAME}"
PKGVER="0.N"

# Setup KindleTool packaging metadata flags to avoid cluttering the invocations
PKGREV="$(svnversion -c .. | awk '{print $NF}' FS=':' | tr -d 'P')"
KT_PM_FLAGS=( "-xPackageName=${HACKDIR}" "-xPackageVersion=${PKGVER}-r${PKGREV}" "-xPackageAuthor=NiLuJe" "-xPackageMaintainer=NiLuJe" "-X" )

# Do we have kindletool (https://github.com/NiLuJe/KindleTool) in $PATH?
if kindletool help &>/dev/null ; then
	USE_KINDLETOOL="true"
fi

# Force use of the python tool
#USE_KINDLETOOL="false"

# Pickup our common stuff... We leave it in our staging wd so it ends up in the source package.
if [[ ! -d "../../Common" ]] ; then
        echo "The tree isn't checked out in full, missing the Common directory..."
        exit 1
fi
# LibOTAUtils
ln -f ../../Common/lib/libotautils ./libotautils

KINDLE_MODELS="k2 k2i dx dxi dxg k3g k3w k3gb"

# OTAv2 MRPI only packages or not?
if [[ "${NO_MRPI_ONLY_PACKAGES}" == "true" ]] ; then
	for model in ${KINDLE_MODELS} ; do
		# Prepare our files for this specific kindle model...
		ARCH=${PKGNAME}_${PKGVER}_${model}

		if [[ "$USE_KINDLETOOL" == "true" ]] ; then
			# Install
			kindletool create ota -d ${model} libotautils install.sh Update_${ARCH}_install.bin
		else
			# Build install update
			./kindle_update_tool.py m --${model} --sign ${ARCH}_install libotautils install.sh
		fi
	done
else
	if [[ "$USE_KINDLETOOL" == "true" ]] ; then
		ARCH="${PKGNAME}_${PKGVER}_k2_dx_k3"
		# Install
		kindletool create ota2 "${KT_PM_FLAGS[@]}" -d legacy libotautils install.sh Update_${ARCH}_install.bin
	fi
fi

# Move our updates :)
mv -f *.bin ../
